@@ -7,29 +7,24 @@ knitr::opts_chunk$set(fig.path="figures/old-faq/")
 set.seed(123)
 source("render_toc.R")
 
-
 ## ----toc, echo=FALSE----------------------------------------------------------
 render_toc("old-faq.Rmd")
 
-
 ## ---- eval=FALSE--------------------------------------------------------------
-##     expression: statement; statement; ...; return(value)
-
+#      expression: statement; statement; ...; return(value)
 
 ## ----eval=FALSE---------------------------------------------------------------
-##     prior.expression = "expression:
-##         a = 1;
-##         b = 0.1;
-##         precision = exp(log_precision);
-##         logdens = log(b^a) - lgamma(a)
-##            + (a-1)*log_precision - b*precision;
-##         log_jacobian = log_precision;
-##         return(logdens + log_jacobian);"
-
+#      prior.expression = "expression:
+#          a = 1;
+#          b = 0.1;
+#          precision = exp(log_precision);
+#          logdens = log(b^a) - lgamma(a)
+#             + (a-1)*log_precision - b*precision;
+#          log_jacobian = log_precision;
+#          return(logdens + log_jacobian);"
 
 ## ----eval=FALSE---------------------------------------------------------------
-##     table: x_1 ... x_n y_1 ... y_n
-
+#      table: x_1 ... x_n y_1 ... y_n
 
 ## -----------------------------------------------------------------------------
 ## the loggamma-prior
@@ -80,7 +75,6 @@ r3 = inla(y~1, data = data.frame(y),
 
 print(round(c(r1$mlik[1], r2$mlik[1], r3$mlik[1]), dig=3))
 
-
 ## -----------------------------------------------------------------------------
 n = 100
 z = rnorm(n)
@@ -105,7 +99,6 @@ rrr = inla(y ~ 1 + z,  data = data.frame(y, z), family = "binomial", Ntrials = r
         control.family = list(control.link = list(model="cloglog")), 
 		control.predictor = list(compute=TRUE))        
 
-
 ## -----------------------------------------------------------------------------
 n = 100
 n.pred = 10
@@ -117,11 +110,9 @@ formula = yy ~ f(i, model="ar1")
 r = inla(formula, data = data.frame(i,yy),
         control.family = list(initial = 10, fixed=TRUE)) ## no observational noise
 
-
 ## -----------------------------------------------------------------------------
 r$summary.random$i[(n+1):N, c("mean", "sd") ]
 
-
 ## ----plot=TRUE----------------------------------------------------------------
 ## simple poisson regression
 n = 100
@@ -143,7 +134,6 @@ r = inla(y ~ 1 + x,  family = "poisson",
 plot(exp(eta),type ="l")
 points(r$summary.fitted.values$mean, pch=19)
 
-
 ## ----plot=T-------------------------------------------------------------------
 n2 = n %/% 2L
 Y = matrix(NA, n, 2)
@@ -155,11 +145,11 @@ link[n2  + which(is.na(y[1:n2 + n2]))] = 2
 
 r = inla(Y ~ 1 + x,  family = c("poisson", "nbinomial"),
         data = list(Y=Y, x=x),
+		control.family= list(list(), list()),
         control.predictor = list(link = link))
 plot(exp(eta),type ="l")
 points(r$summary.fitted.values$mean, pch=19)
 
-
 ## -----------------------------------------------------------------------------
 ## Load the data
 data(Tokyo)
@@ -202,90 +192,71 @@ for(i in 1:366) {
 }
 plot(fitted.values.mean)
 
-
 ## ---- eval=FALSE--------------------------------------------------------------
-## 4
-## 1 2 3 4
-## 2 0
-## 3 1 1
-## 4 1 1
-
+#  4
+#  1 2 3 4
+#  2 0
+#  3 1 1
+#  4 1 1
 
 ## ----plot=TRUE,fig.width=2,fig.align='center'---------------------------------
 g = inla.read.graph("4 1 2 3 4 2 0 3 1 1 4 1 1")
 plot(g)
 
+## ----eval=FALSE---------------------------------------------------------------
+#  "4 1 2 3 4  2 0 3 1 1 4 1 1"
 
 ## ----eval=FALSE---------------------------------------------------------------
-## "4 1 2 3 4  2 0 3 1 1 4 1 1"
-
+#  formula = y ~ f(idx, model = "besag", graph = "graph.dat")
 
 ## ----eval=FALSE---------------------------------------------------------------
-## formula = y ~ f(idx, model = "besag", graph = "graph.dat")
-
-
-## ----eval=FALSE---------------------------------------------------------------
-## formula = y ~ f(idx, model = "besag", graph = "4 1 2 3 4  2 0 3 1 1 4 1 1")
-
+#  formula = y ~ f(idx, model = "besag", graph = "4 1 2 3 4  2 0 3 1 1 4 1 1")
 
 ## -----------------------------------------------------------------------------
 C = matrix(c(1, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 0, 0, 1),4,4)
 C
 
-
 ## -----------------------------------------------------------------------------
 C.sparse= inla.as.sparse(C)
 C.sparse
 
-
 ## -----------------------------------------------------------------------------
 str(g)
 
-
 ## ----eval=FALSE---------------------------------------------------------------
-## formula = y ~ x + f(k, model= <some model>)
-
+#  formula = y ~ x + f(k, model= <some model>)
 
 ## ----eval=F-------------------------------------------------------------------
-## control.fixed = list(expand.factor.strategy = "inla")
-
+#  control.fixed = list(expand.factor.strategy = "inla")
 
 ## -----------------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3, x=factor(c("a","b","c"))))
 as.matrix(r$model.matrix)
 
-
 ## -----------------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3,x=factor(c("a","b","c"))), 
          control.fixed = list(expand.factor.strategy="inla"))
 as.matrix(r$model.matrix)
 
-
 ## -----------------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3,x=factor(c("a","b",NA))), 
          control.fixed = list(expand.factor.strategy="inla"))
 as.matrix(r$model.matrix)
 
+## ----eval=FALSE---------------------------------------------------------------
+#  control.compute=list(cpo=TRUE)
 
 ## ----eval=FALSE---------------------------------------------------------------
-## control.compute=list(cpo=TRUE)
-
+#  improved.result = inla.cpo(result)
 
 ## ----eval=FALSE---------------------------------------------------------------
-## improved.result = inla.cpo(result)
-
+#  r = inla(..., inla.call = "submit")
 
 ## ----eval=FALSE---------------------------------------------------------------
-## r = inla(..., inla.call = "submit")
-
+#  inla.qstat()
 
 ## ----eval=FALSE---------------------------------------------------------------
-## inla.qstat()
-
-
-## ----eval=FALSE---------------------------------------------------------------
-## r = inla.qget(r)
-
+#  r = inla.qget(r)
 
 ## -----------------------------------------------------------------------------
 ## A simple model
@@ -323,7 +294,6 @@ lc1.1 = 2 * r$summary.fixed["a", "mean"] + 3 * r$summary.fixed["b",
 lc1.2= r$summary.lincomb.derived$mean
 print(round(c(lc1.1 = lc1.1, lc1.2 = lc1.2), dig=3))
 
-
 ## -----------------------------------------------------------------------------
 ## let wa and wb be vectors, and we want to compute the marginals for
 ## beta_a * wa[i] + beta_b * wb[i], for i=1..m. this is done
@@ -341,14 +311,11 @@ r = inla(formula, data = data.frame(a,b,y),
         control.family = list(initial=10, fixed=TRUE))
 print(round(r$summary.lincomb.derived, dig=3))
 
+## ----eval=FALSE---------------------------------------------------------------
+#  control.inla = list(lincomb.derived.correlation.matrix = TRUE)
 
 ## ----eval=FALSE---------------------------------------------------------------
-## control.inla = list(lincomb.derived.correlation.matrix = TRUE)
-
-
-## ----eval=FALSE---------------------------------------------------------------
-## result$misc$lincomb.derived.correlation.matrix
-
+#  result$misc$lincomb.derived.correlation.matrix
 
 ## -----------------------------------------------------------------------------
 n = 100
@@ -371,11 +338,11 @@ lcs = inla.make.lincombs(Predictor = B)
 r = inla(formula,  data = data.frame(Y, time),
         control.predictor = list(compute=TRUE),
         lincomb = lcs,
+		inla.mode="classic",
         control.inla = list(lincomb.derived.correlation.matrix=TRUE))
 
 print(round(r$misc$lincomb.derived.correlation.matrix,dig=3))
 
-
 ## -----------------------------------------------------------------------------
 n = 100
 u = rnorm(n)
@@ -391,7 +358,6 @@ result = inla(y ~ 1 + f(idx, model="iid",
 	          Ntrials = 1)
 summary(result)
 
-
 ## -----------------------------------------------------------------------------
 ## simple example
 n = 100
@@ -455,24 +421,19 @@ r = inla(formula,
 
 summary(r)
 
-
 ## -----------------------------------------------------------------------------
 inla.list.models()
 
+## ----eval=FALSE---------------------------------------------------------------
+#  y = a + b*w + ...
 
 ## ----eval=FALSE---------------------------------------------------------------
-## y = a + b*w + ...
-
+#  f(idx, model="iid2d", n=2*m, ...)
 
 ## ----eval=FALSE---------------------------------------------------------------
-## f(idx, model="iid2d", n=2*m, ...)
-
-
-## ----eval=FALSE---------------------------------------------------------------
-## idx = 1:m
-## idx.copy = m + 1:m
-## formula = y ~  f(idx, model="iid2d", n=2*m) + f(idx.copy, w, copy="idx") + ....
-
+#  idx = 1:m
+#  idx.copy = m + 1:m
+#  formula = y ~  f(idx, model="iid2d", n=2*m) + f(idx.copy, w, copy="idx") + ....
 
 ## -----------------------------------------------------------------------------
 n=1000
@@ -486,25 +447,20 @@ formula = y ~ f(i, model="iid",initial=0, fixed=T) +
 r = inla(formula, data = data.frame(i,j,w,y))
 summary(r)
 
+## ----eval=FALSE---------------------------------------------------------------
+#  beta = low + (high-low)*exp(beta.local)/(1+exp(beta.local))
 
 ## ----eval=FALSE---------------------------------------------------------------
-## beta = low + (high-low)*exp(beta.local)/(1+exp(beta.local))
-
+#  f(idx, model = ..,  replicate = r)
 
 ## ----eval=FALSE---------------------------------------------------------------
-## f(idx, model = ..,  replicate = r)
-
+#  i = 1:n
+#  formula = y ~  f(i, model = "iid") + ...
 
 ## ----eval=FALSE---------------------------------------------------------------
-## i = 1:n
-## formula = y ~  f(i, model = "iid") + ...
-
-
-## ----eval=FALSE---------------------------------------------------------------
-## i = rep(1,n)
-## r = 1:n
-## formula = y ~  f(i, model="iid", replicate = r) + ...
-
+#  i = rep(1,n)
+#  r = 1:n
+#  formula = y ~  f(i, model="iid", replicate = r) + ...
 
 ## -----------------------------------------------------------------------------
 n = 100
@@ -522,10 +478,8 @@ result = inla(formula, family = "gaussian",
               control.family = list(initial = 12, fixed=TRUE))
 summary(result)
 
-
 ## ----eval=FALSE---------------------------------------------------------------
-## y ~ a + 1
-
+#  y ~ a + 1
 
 ## -----------------------------------------------------------------------------
 ##  Simple linear regression with observations with two different
@@ -551,7 +505,6 @@ result = inla(
                             list()))
 summary(result)
 
-
 ## -----------------------------------------------------------------------------
 ## Simple example with two types of likelihoods
 n = 10
@@ -595,22 +548,21 @@ formula = Y ~ X - 1
 ## `family' is now
 result = inla(formula,
         family = c("poisson", "binomial"),
+		control.family=list(list(), list()),
         data = list(Y=Y, X=X),
         E = E, Ntrials = Ntrials)
 summary(result)
 
-
 ## ----eval=FALSE---------------------------------------------------------------
-## X = numeric(N)
-## X[1:n] = x
-## X[1:n + n] = NA
-## 
-## XX = numeric(N)
-## XX[1:n] = NA
-## XX[1:n + n] = xx
-## 
-## formula = Y  ~ X + XX -1
-
+#  X = numeric(N)
+#  X[1:n] = x
+#  X[1:n + n] = NA
+#  
+#  XX = numeric(N)
+#  XX[1:n] = NA
+#  XX[1:n + n] = xx
+#  
+#  formula = Y  ~ X + XX -1
 
 ## -----------------------------------------------------------------------------
 ## An example with three independent AR(1)'s with separate means, but
@@ -647,46 +599,39 @@ formula = y ~ f(i, model="ar1", replicate=r, constr=TRUE) + rf -1
 data = list(y=y, i=i, r=r, rf=rf)
 
 ## parameters for the binomial and the poisson
-Ntrial = rep(NA, 3*n)
-Ntrial[1:n] = Nt
+Ntrials = rep(NA, 3*n)
+Ntrials[1:n] = Nt
 E = rep(NA, 3*n)
 E[1:n + n] = Ep
 
 result = inla(formula, family = c("binomial", "poisson", "normal"),
-              data = data, Ntrial = Ntrial, E = E,
+              data = data, Ntrials = Ntrials, E = E,
               control.family = list(
                       list(),
                       list(),
                       list()))
 summary(result)
 
+## ----eval=FALSE---------------------------------------------------------------
+#  y ~ 1 + z
 
 ## ----eval=FALSE---------------------------------------------------------------
-## y ~ 1 + z
-
+#  eta~ = A %*% eta
 
 ## ----eval=FALSE---------------------------------------------------------------
-## eta~ = A %*% eta
-
+#  y ~ 1 + z, with addition matrix A
 
 ## ----eval=FALSE---------------------------------------------------------------
-## y ~ 1 + z, with addition matrix A
-
+#  y    ~ eta~   ## no intercept...
+#  eta~ = A %*% eta
+#  eta  = intercept + beta*z
 
 ## ----eval=FALSE---------------------------------------------------------------
-## y    ~ eta~   ## no intercept...
-## eta~ = A %*% eta
-## eta  = intercept + beta*z
-
+#  control.predictor=list(A=A)
 
 ## ----eval=FALSE---------------------------------------------------------------
-## control.predictor=list(A=A)
-
-
-## ----eval=FALSE---------------------------------------------------------------
-## eta~ = A %*% eta + offset.arg
-## eta = intercept + beta*z + offset.formula
-
+#  eta~ = A %*% eta + offset.arg
+#  eta = intercept + beta*z + offset.formula
 
 ## -----------------------------------------------------------------------------
 ## 'm' is the number of observations of eta*, where eta* = A eta +
@@ -735,10 +680,8 @@ summary(r)
 ## this should be a small number
 print(max(abs(r$summary.linear.predictor$mean - c(Eta, eta))))
 
-
 ## ----eval=FALSE---------------------------------------------------------------
-## y = intercept + s[j] + 0.5*s[k] + noise
-
+#  y = intercept + s[j] + 0.5*s[k] + noise
 
 ## ----plot=TRUE----------------------------------------------------------------
 n = 100
